#
# spec file for package hyprcursor
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2024 Florian "sp1rit" <sp1rit@disroot.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover 0

Name:           hyprcursor
Version:        0.1.9
Release:        1.1
Summary:        Library and utilities for the hyprland cursor format
License:        BSD-3-Clause
URL:            https://wiki.hyprland.org/hypr-ecosystem/hyprcursor/
Source0:        %{name}-%{version}.tar.xz
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  pkg-config
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(hyprlang) >= 0.4.2
BuildRequires:  pkgconfig(librsvg-2.0)
BuildRequires:  pkgconfig(libzip)
BuildRequires:  pkgconfig(tomlplusplus) >= 3.4.0

%description
Utilities for the hyprland cursor format.

%package -n lib%{name}%{sover}
Summary:        Library for the hyprland cursor format
Group:          System/Libraries

%description -n lib%{name}%{sover}
Library for handling the hyprlang cursor format.

%package devel
Summary:        Development files for hyprcursor
Group:          Development/Libraries/Other
Requires:       lib%{name}%{sover} = %{version}

%description devel
Library for handling the hyprland cursor format.

This subpackage contains development files for hyprcursor.

%prep
%autosetup -p1

%build
%cmake
%cmake_build

%install
%cmake_install
%fdupes %{buildroot}/%{_includedir}/

%post   -n lib%{name}%{sover} -p /sbin/ldconfig
%postun -n lib%{name}%{sover} -p /sbin/ldconfig

%files
%license LICENSE
%doc README.md
%doc docs/MAKING_THEMES.md
%{_bindir}/%{name}-util

%files -n lib%{name}%{sover}
%license LICENSE
%doc docs/END_USERS.md
%{_libdir}/lib%{name}.so.%{sover}
%{_libdir}/lib%{name}.so.%{version}

%files devel
%doc docs/DEVELOPERS.md
%{_includedir}/%{name}
%{_includedir}/%{name}.hpp
%{_libdir}/lib%{name}.so
%{_libdir}/pkgconfig/%{name}.pc

%changelog
* Mon Jun 10 2024 Florian "spirit" <sp1rit@disroot.org>
- Update to version 0.1.9:
  + A small housekeeping update with a few minor patches.
  + Fixes:
  - fixed nearest size search for png cursor themes
  - Fixed getconf command in build instructions
  - add option to not use default fallbacks (env and first
    available)
- Changes from version 0.1.8:
  + A minor update with some cleanups
  + Fixes:
  - util: fixed printing overrides
  - Count cursor-less themes as invalid
  + Other:
  - Add validation for cursor file names and propagate the error
    from parsing HL cursor
  - Properly report error on zip_close
* Sat Apr 13 2024 Florian "sp1rit" <sp1rit@disroot.org>
- Update to 0.1.7:
  + A small patch to fix 0.1.6's accidental toml / theme finding
    regressions
  + Fixes:
  - lib: fixes to toml manifest searching and extensions when
    packing
  - lib: fixed missing overrides
  - lib: fixed manifest reading permission issues
  - lib: round hotspots in getShapes
- Changes from update 0.1.6:
  + A small patch to hyprcursor to fix some permission issues and add
    a few stuff KDE requested.
    (This release is ABI-compatible with 0.1.5)
  + New stuff:
  - Added user-defined logging
  - Added a raw data API
  - Added support for .toml wherever .hl is used
  + Fixes:
  - Fixed up permission issues on themes
- Changes from update 0.1.5:
  + A small update to fix a few minor annoyances.
  + New stuff:
  - lib: avoid arithmetic on void*
  - util: wrap paths in quotes in shell invocations
  - lib: accept theme names for lookup
  - lib: set size to 0 for svg images
- Dropped "fix_include_dir_permissions.patch" as the fix has been
  included upstream.
* Sat Mar 16 2024 Florian "sp1rit" <sp1rit@disroot.org>
- Initial packaging of verion 0.1.4
